@@ -52,7 +52,7 @@
 #define R__HAS_DATAFRAME /**/
 #define R__HAS_ROOT7 /**/
 #undef R__LESS_INCLUDES /**/
-#undef R__HAS_TBB /**/
+#define R__HAS_TBB /**/
 
 #if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
 #ifndef VECCORE_ENABLE_VC
